.. _whatis:

What is Globus Provision?
==============================

.. include:: intro_common.rst

To learn more about Globus Provision, take a look at the :ref:`Globus Provision Documentation <docs>`,
or get started right away with our :ref:`Quickstart Guide <chap_quickstart>`.